Module utility

Module utility 

Allocation-free utilities for runtime dispatch and groups of state machines.

Structs

DispatchStatus
Result reported by a queued dispatch callback.
DispatchSummary
Aggregate result of an external dispatch and the queue work it triggered.
DispatchTable
Routes a runtime event ID to one of a contiguous set of typed handlers.
EventQueue
Allocation-free FIFO used for deferred and explicitly processed events.
EventQueues
Separate bounded queues for deferred events and events requested by actions.
Hierarchical
Parent and child state machines with child-first event routing and retained shallow history.
IndexedEvent
Associates an event with the index of the machine that should receive it.
OrthogonalRegions
A set of simultaneously active state-machine regions.
QueueFull
Error returned when a bounded event queue has no remaining capacity.
SmPool
A storage-generic pool of state machines.

Enums

HierarchicalDispatch
Result of hierarchical child-first event routing.

Functions

with_id
Creates an indexed event for heterogeneous batch dispatch.